@@ -1999,6 +1999,10 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return json.loads(response.text)["supportedLanguages"]
 
+    def devicee(self):
+        dev=requests.get("https://devgen17.herokuapp.com/dev")
+        return dev.json()["dev"]
+
     def claim_new_user_coupon(self):
         """
         Claim the New User Coupon available when a new account is created.
